' TripleSix's Server Uptime Script
'
' v1.1
'
' This script requires DSPing by Donia Software (included in this package)
' Please read the install instructions in the DSPing directory
'
'
' Parameters
'   - ServerName  : Computer name of the server
'   - IP_Addr     : IP address of the server (only necessary when remote computer doesn't allow WMI access)
'   - AdminName   : Login name of remote computer's administrator
'   - Password    : Admin's password
'   - Format      :
'        %d  = total in days
'        %h  = total in hours
'        %H  = hours in 0-23 format
'        %_H = hours in 00-23 format (leading zero)
'        %m  = total in minutes
'        %M  = minutes in 0-59 format
'        %_M = minutes in 00-59 format (leading zero)
'        %s  = total in seconds
'        %S  = seconds in 0-59 format
'        %_S = seconds in 00-59 format (leading zero)
'
' Example: %dd %Hh %Mm -- outputs: 203d 15h 3m  (fictional values)
'
' Using execution intervals of second(s) can affect your system's performance.
' Intervals of 1 minute or more is recommended
'
' Below are the default strings to display when
'   - strPingOnline  : ...the computer is turned on, but the uptime information could not be retrieved (eg. when remote is running WinXP Home)
'   - strPingOffline : ...the computer is turned off
'   - strError       : ...an error occured when trying to retrieve the uptime info
'
' Feel free to change them to your likings :)
'

strPingOnline  = "Online"
strPingOffline = "Offline"
strError       = "Error"

Function GetRemoteUptime(ServerName, IP_Addr, AdminName, Password, Format)
    Dim objWMIService
    Dim objItem
    Dim BootDT
    Dim strOutput
    On Error Resume Next

    Set dtmConvertedDate = CreateObject("WbemScripting.SWbemDateTime")
    Set objSWbemLocator = CreateObject("WbemScripting.SWbemLocator")
        
    Set objSWbemServices = objSWbemLocator.ConnectServer (ServerName, "root\cimv2", AdminName, Password)
    If Err.Number Then
        Set Pinger = CreateObject("DSPing.Ping")
        DoPing = Pinger.DoPing(IP_Addr)
        If DoPing <> 0 Then
            strOutput = strPingOffline
        Else
            strOutput = strPingOnline
        End If
        Err.Clear
    Else
        objSWbemServices.Security_.ImpersonationLevel = 3
        Set colSWbemObjectSet = objSWbemServices.ExecQuery ("Select * From Win32_OperatingSystem")
        For Each objItem in colSWbemObjectSet
            dtmConvertedDate.Value = objItem.LastBootUpTime
            BootDT = dtmConvertedDate.GetVarDate
        Next

        Uptime = DateDiff ("s", BootDT, Now )
        strOutput = Format
        strOutput = Replace(strOutput, "%d", Int(Uptime / 86400))
        strOutput = Replace(strOutput, "%h", Int(Uptime / 3600))
        strOutput = Replace(strOutput, "%H", Int(Uptime / 3600) mod 24)
        strOutput = Replace(strOutput, "%_H", Right( "0" & Int(Uptime / 3600) mod 24, 2) )
        strOutput = Replace(strOutput, "%m", Int(Uptime / 60))
        strOutput = Replace(strOutput, "%M", Int(Uptime / 60) mod 60)
        strOutput = Replace(strOutput, "%_M", Right( "0" & Int(Uptime / 60) mod 60, 2) )
        strOutput = Replace(strOutput, "%s", Uptime)
        strOutput = Replace(strOutput, "%S", Uptime mod 60)
        strOutput = Replace(strOutput, "%_S", Right( "0" & Uptime mod 60, 2) )
    End If
GetRemoteUptime = strOutput
End Function

Function GetLocalUptime(Format)
    Dim objWMIService
    Dim objItem
    Dim BootDT
    Dim strOutput
    On Error Resume Next

    Set dtmConvertedDate = CreateObject("WbemScripting.SWbemDateTime")
    Set objSWbemLocator = CreateObject("WbemScripting.SWbemLocator")

    Set objWMIService = GetObject("winmgmts:\\.\root\cimv2")
    If Err.Number Then
        strOutput = strError
        Err.Clear
    Else
        Set colWMIObjectSet = objWMIService.ExecQuery ("Select * From Win32_OperatingSystem")
        For Each objItem in colWMIObjectSet
            dtmConvertedDate.Value = objItem.LastBootUpTime
            BootDT = dtmConvertedDate.GetVarDate
            strOutput = BootDT
        Next

        Uptime = DateDiff ("s", BootDT, Now )
        strOutput = Format
        strOutput = Replace(strOutput, "%d", Int(Uptime / 86400))
        strOutput = Replace(strOutput, "%h", Int(Uptime / 3600))
        strOutput = Replace(strOutput, "%H", Int(Uptime / 3600) mod 24)
        strOutput = Replace(strOutput, "%_H", Right( "0" & Int(Uptime / 3600) mod 24, 2) )
        strOutput = Replace(strOutput, "%m", Int(Uptime / 60))
        strOutput = Replace(strOutput, "%M", Int(Uptime / 60) mod 60)
        strOutput = Replace(strOutput, "%_M", Right( "0" & Int(Uptime / 60) mod 60, 2) )
        strOutput = Replace(strOutput, "%s", Uptime)
        strOutput = Replace(strOutput, "%S", Uptime mod 60)
        strOutput = Replace(strOutput, "%_S", Right( "0" & Uptime mod 60, 2) )
    End If
GetLocalUptime = strOutput
End Function
